@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkPolarAxesActor extends vtkActor
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -55,73 +55,73 @@ public class vtkPolarAxesActor extends vtkActor
   public void LogOff()
     { LogOff_11(); }
 
-  private native void SetNumberOfRadialAxes_12(int id0);
-  public void SetNumberOfRadialAxes(int id0)
-    { SetNumberOfRadialAxes_12(id0); }
+  private native void SetRequestedNumberOfRadialAxes_12(int id0);
+  public void SetRequestedNumberOfRadialAxes(int id0)
+    { SetRequestedNumberOfRadialAxes_12(id0); }
 
-  private native int GetNumberOfRadialAxes_13();
-  public int GetNumberOfRadialAxes()
-    { return GetNumberOfRadialAxes_13(); }
+  private native int GetRequestedNumberOfRadialAxesMinValue_13();
+  public int GetRequestedNumberOfRadialAxesMinValue()
+    { return GetRequestedNumberOfRadialAxesMinValue_13(); }
 
-  private native void SetNumberOfPolarAxisTicks_14(int id0);
+  private native int GetRequestedNumberOfRadialAxesMaxValue_14();
+  public int GetRequestedNumberOfRadialAxesMaxValue()
+    { return GetRequestedNumberOfRadialAxesMaxValue_14(); }
+
+  private native int GetRequestedNumberOfRadialAxes_15();
+  public int GetRequestedNumberOfRadialAxes()
+    { return GetRequestedNumberOfRadialAxes_15(); }
+
+  private native void SetNumberOfPolarAxisTicks_16(int id0);
   public void SetNumberOfPolarAxisTicks(int id0)
-    { SetNumberOfPolarAxisTicks_14(id0); }
+    { SetNumberOfPolarAxisTicks_16(id0); }
 
-  private native int GetNumberOfPolarAxisTicks_15();
+  private native int GetNumberOfPolarAxisTicks_17();
   public int GetNumberOfPolarAxisTicks()
-    { return GetNumberOfPolarAxisTicks_15(); }
+    { return GetNumberOfPolarAxisTicks_17(); }
 
-  private native void SetAutoSubdividePolarAxis_16(boolean id0);
+  private native void SetAutoSubdividePolarAxis_18(boolean id0);
   public void SetAutoSubdividePolarAxis(boolean id0)
-    { SetAutoSubdividePolarAxis_16(id0); }
+    { SetAutoSubdividePolarAxis_18(id0); }
 
-  private native boolean GetAutoSubdividePolarAxis_17();
+  private native boolean GetAutoSubdividePolarAxis_19();
   public boolean GetAutoSubdividePolarAxis()
-    { return GetAutoSubdividePolarAxis_17(); }
+    { return GetAutoSubdividePolarAxis_19(); }
 
-  private native void AutoSubdividePolarAxisOn_18();
+  private native void AutoSubdividePolarAxisOn_20();
   public void AutoSubdividePolarAxisOn()
-    { AutoSubdividePolarAxisOn_18(); }
+    { AutoSubdividePolarAxisOn_20(); }
 
-  private native void AutoSubdividePolarAxisOff_19();
+  private native void AutoSubdividePolarAxisOff_21();
   public void AutoSubdividePolarAxisOff()
-    { AutoSubdividePolarAxisOff_19(); }
+    { AutoSubdividePolarAxisOff_21(); }
 
-  private native void SetRange_20(double id0,double id1);
+  private native void SetRange_22(double id0,double id1);
   public void SetRange(double id0,double id1)
-    { SetRange_20(id0,id1); }
+    { SetRange_22(id0,id1); }
 
-  private native void SetRange_21(double id0[]);
+  private native void SetRange_23(double id0[]);
   public void SetRange(double id0[])
-    { SetRange_21(id0); }
+    { SetRange_23(id0); }
 
-  private native double[] GetRange_22();
+  private native double[] GetRange_24();
   public double[] GetRange()
-    { return GetRange_22(); }
+    { return GetRange_24(); }
 
-  private native void SetMinimumRadius_23(double id0);
+  private native void SetMinimumRadius_25(double id0);
   public void SetMinimumRadius(double id0)
-    { SetMinimumRadius_23(id0); }
+    { SetMinimumRadius_25(id0); }
 
-  private native double GetMinimumRadius_24();
+  private native double GetMinimumRadius_26();
   public double GetMinimumRadius()
-    { return GetMinimumRadius_24(); }
+    { return GetMinimumRadius_26(); }
 
-  private native void SetMaximumRadius_25(double id0);
+  private native void SetMaximumRadius_27(double id0);
   public void SetMaximumRadius(double id0)
-    { SetMaximumRadius_25(id0); }
+    { SetMaximumRadius_27(id0); }
 
-  private native double GetMaximumRadius_26();
+  private native double GetMaximumRadius_28();
   public double GetMaximumRadius()
-    { return GetMaximumRadius_26(); }
-
-  private native void SetAutoScaleRadius_27(boolean id0);
-  public void SetAutoScaleRadius(boolean id0)
-    { SetAutoScaleRadius_27(id0); }
-
-  private native boolean GetAutoScaleRadius_28();
-  public boolean GetAutoScaleRadius()
-    { return GetAutoScaleRadius_28(); }
+    { return GetMaximumRadius_28(); }
 
   private native void SetMinimumAngle_29(double id0);
   public void SetMinimumAngle(double id0)
